Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'add_advanced_objects_panels/object_laplace_lightning.py')
-rw-r--r--add_advanced_objects_panels/object_laplace_lightning.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/add_advanced_objects_panels/object_laplace_lightning.py b/add_advanced_objects_panels/object_laplace_lightning.py
index f653de53..15e6730f 100644
--- a/add_advanced_objects_panels/object_laplace_lightning.py
+++ b/add_advanced_objects_panels/object_laplace_lightning.py
@@ -514,7 +514,7 @@ def writeStokeToSingleMesh(arr, jarr, orig, gs, mct, rpt=None):
def visualizeArray(cg, oob, gs, vm, vs, vc, vv, rst):
winmgr = bpy.context.scene.advanced_objects1
# IN: (cellgrid, origin, gridscale,
- # mulimesh, single mesh, cubes, voxels, report sting)
+ # mulimesh, single mesh, cubes, voxels, report string)
origin = oob.location
# deal with vert multi-origins
@@ -613,7 +613,7 @@ def buildCPGraph_WORKINPROGRESS(arr, sti=2):
def findChargePath(oc, fc, ngraph, restrict=[], partial=True):
# oc -origin charge index, fc -final charge index
# ngraph -node graph, restrict- index of sites cannot traverse
- # partial -return partial path if restriction encounterd
+ # partial -return partial path if restriction encountered
cList = splitList(ngraph, 0)
pList = splitList(ngraph, 1)
aRi = []
@@ -764,7 +764,7 @@ def classifyStroke(sarr, mct, hORDER=1):
aTIPSi = findTips(sgarr)
# find horder channel roots
- # hcount = orders bewteen main and side/tips
+ # hcount = orders between main and side/tips
# !!!still buggy!!!
hRESTRICT = list(aMAINi) # add to this after each time
allHPATHSi = [] # all ho paths: [[h0], [h1]...]
@@ -794,7 +794,7 @@ def classifyStroke(sarr, mct, hORDER=1):
hRESTRICT += hri
curPATHSi = aHPATHSi
- # side branches, final order of heirarchy
+ # side branches, final order of hierarchy
# from tips that are not in an existing path
# back to any other point that is already on a path
aDRAWNi = []
@@ -1159,13 +1159,13 @@ def FSLG():
winmgr.ORIGIN = obORIGIN.location
winmgr.GROUNDZ = int((obGROUND.location[2] - winmgr.ORIGIN[2]) / winmgr.GSCALE)
# 1) insert intial charge(s) point (uses verts if mesh)
cgrid = [(0, 0, 0)]
if obORIGIN.type == 'MESH':
debug_prints(
func="FSLG",
- text="Origin object is mesh, 'voxelizing' intial charges from verts"
+ text="Origin object is mesh, 'voxelizing' initial charges from verts"
)
cgrid = voxelByVertex(obORIGIN, winmgr.GSCALE)
@@ -1159,13 +1159,13 @@ def FSLG():
winmgr.ORIGIN = obORIGIN.location
winmgr.GROUNDZ = int((obGROUND.location[2] - winmgr.ORIGIN[2]) / winmgr.GSCALE)
- # 1) insert intial charge(s) point (uses verts if mesh)
+ # 1) insert initial charge(s) point (uses verts if mesh)
cgrid = [(0, 0, 0)]
if obORIGIN.type == 'MESH':